package reliable;

import java.io.IOException;

import com.epoll.EpollClientImpl;

import Interface.IUdpReceiver;
import UdpException.UDPSendException;


public class ReliableUDPClient {
	
	private EpollClientImpl epollClientImp;

	/**
	 * 
	 * @param port 绑定一个端口 小于1025 就不绑定
	 * @param iSocketReceiver 接收数据回调
	 */
	public ReliableUDPClient(int port,IUdpReceiver iSocketReceiver){
		epollClientImp = new EpollClientImpl(port, iSocketReceiver);
	}
	
	
	/**
	 * 
	 * @return 服务端设备 客户端主动连服务器
	 * @throws IOException
	 */
	@SuppressWarnings("deprecation")
	public void connect(String ip,int port) throws Exception {
		if(epollClientImp.connect(ip, port) != 1) {
			throw new IOException("udp connect failed");
		}
	}
	
	/**
	 * 发送数据函数
	 * @param device 对端设备
	 * @param data 有效数据
	 * @param type 数据类型
	 * @throws UDPSendException 对方设备没回复此包是否收到 那么抛出此异常 可以认为对端网络出现错误
	 */
	public void sendData(byte type,byte[] data) throws UDPSendException {
		if(epollClientImp.sendData(type ,data) != 1) {
			throw new UDPSendException("the udp remote device is closed");
		}
	}
	
	/**
	 * 发送心跳包
	 * @param device 对端设备
	 * @param timespace 间隔多久发一次
	 * @throws UDPSendException  对方设备没回复此包是否收到 那么抛出此异常 可以认为对端网络出现错误 
	 */
	public void startHeart(int timespace) throws UDPSendException {
		if(epollClientImp.startHeart(timespace) != 1) {
			throw new UDPSendException("the udp remote device is closed");
		}
	}
	
	/**
	 * 这个对象不使用了才需要释放
	 */
	public void release() {
		epollClientImp.release();
	}
	
}
