package reliable;

import com.epoll.EpollServerImpl;

import Interface.IUdpReceiver;
import UdpException.UDPAcceptTimeOutException;
import UdpException.UDPSendException;

public class ReliableUDPServer {

	private EpollServerImpl epollServerImp;

	/**
	 * 
	 * @param port 绑定一个端口 小于1025 就不绑定
	 * @param iSocketReceiver 接收数据回调
	 */
	@SuppressWarnings("resource")
	public ReliableUDPServer(int port,IUdpReceiver iSocketReceiver) {
		epollServerImp = new EpollServerImpl(port, iSocketReceiver);
	}
	
	/**
	 * @param timeout 小于0 阻塞
	 * @return 客户端设备信息 等待客户端连接
	 * @throws UDPAcceptTimeOutException udp服务器连接超时
	 */
	public void accept(int timeout) throws UDPAcceptTimeOutException {
		if(epollServerImp.accept(timeout) != 1) {
			throw new UDPAcceptTimeOutException("udp server accept time out");
		}
	}
	/**
	 * 发送数据函数
	 * @param data 有效数据
	 * @param type 数据类型
	 * @throws UDPSendException 对方设备没回复此包是否收到 那么抛出此异常 可以认为对端网络出现错误
	 */
	public void sendData(byte type,byte[] data) throws UDPSendException {
		if(epollServerImp.sendData(type ,data) != 1) {
			throw new UDPSendException("the udp remote device is closed");
		}
	}
	
	/**
	 * 发送心跳包
	 * @param timespace 间隔多久发一次
	 * @throws UDPSendException  对方设备没回复此包是否收到 那么抛出此异常 可以认为对端网络出现错误 
	 */
	public void startHeart(int timespace) throws UDPSendException {
		if(epollServerImp.startHeart(timespace) != 1) {
			throw new UDPSendException("the udp remote device is closed");
		}
	}
	

	/**
	 * 这个对象不使用了才需要释放
	 */
	public void release() {
		epollServerImp.release();
	}
	
}
